@@ -1,20 +1,13 @@
 import os
 
-from deprecated import deprecated
-
 from datagen import modalities
 from datagen.components.datapoint.entity import base
 
 
 class DataPoint(base.DataPoint):
     @modalities.textual_modality
-    def actors(self) -> modalities.TextualModality:
-        return modalities.TextualModality(factory_name="actors", file_name="actor_metadata.json")
-
-    @property
-    @deprecated(reason="Modality name changed to 'actors' (For HIC datapoints only!), please use new name instead")
     def actor_metadata(self) -> modalities.TextualModality:
-        return self.actors
+        return modalities.TextualModality(factory_name="actors", file_name="actor_metadata.json")
 
     @modalities.textual_modality
     def keypoints(self) -> modalities.TextualModality:
