@@ -15,7 +15,7 @@ class Scene:
         self.cameras = self._init_cameras()
 
     def _init_cameras(self) -> List[Camera]:
-        return [Camera(name=camera_name, scene_path=self.path) for camera_name in self._get_cameras_names()]
+        return [Camera(name=camera_name, scene_path=self.path) for camera_name in sorted(self._get_cameras_names())]
 
     def _get_cameras_names(self) -> List[str]:
         return list(set(cam_dir.name for cam_dir in self.path.rglob("*camera*") if cam_dir.is_dir()))
