@@ -9,16 +9,16 @@ from datagen.modalities.textual.base.containers import (
 
 class ActorMetadataModalityContainer(containers.DeclarativeContainer):
 
-    from .actor_metadata import v1
+    from .actor_metadata import ActorMetadata
 
-    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=v1.ActorMetadata)})
+    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=ActorMetadata)})
 
 
 class FaceBoundingBoxModalityContainer(containers.DeclarativeContainer):
 
-    from .face_bounding_box import v1
+    from .face_bounding_box import FaceBoundingBox
 
-    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=v1.FaceBoundingBox)})
+    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=FaceBoundingBox)})
 
 
 class KeypointsModalityContainer(containers.DeclarativeContainer):
@@ -30,7 +30,17 @@ class KeypointsModalityContainer(containers.DeclarativeContainer):
     )
 
 
+class LightsMetadataModalityContainer(containers.DeclarativeContainer):
+
+    from .lights_metadata import LightsMetadata
+
+    create = providers.FactoryAggregate({1: modality_dataclass_factory(clazz=LightsMetadata)})
+
+
 class IdentitiesModalitiesContainer(BaseModalitiesContainer):
+    lights_metadata = providers.Callable(
+        modality_factory, modality_container=providers.Container(LightsMetadataModalityContainer)
+    )
 
     actor_metadata = providers.Callable(
         modality_factory, modality_container=providers.Container(ActorMetadataModalityContainer)
@@ -41,3 +51,7 @@ class IdentitiesModalitiesContainer(BaseModalitiesContainer):
     )
 
     keypoints = providers.Callable(modality_factory, modality_container=providers.Container(KeypointsModalityContainer))
+
+    lights_metadata = providers.Callable(
+        modality_factory, modality_container=providers.Container(LightsMetadataModalityContainer)
+    )
